@@ -15,13 +15,13 @@ def ms(query: str):
     """
 
 
-    temp = re.findall(r'\d+', str(query))
+    temp = re.findall(pattern = r'^(-?(?:\d+)?.?\d+) *(milliseconds?|msecs?|ms|seconds?|secs?|s|minutes?|mins?|m|hours?|hrs?|h|days?|d|weeks?|w|years?|yrs?|y)?$', string = query, flags = re.I)
+    if temp == []:
+    	return None
 
-    res = list(map(int, temp))
-    number = int(res[0])
-
-    mat = str(query)[int(len(str(number))):]
+    number = int(temp[0][0])
 
+    mat = temp[0][1]
     if mat == 'm' or mat == 'min' or mat == 'minute':
         return m * number
     elif mat == 'h' or mat == 'ho' or mat == 'hour':
